@@ -1,6 +1,17 @@
 from skt.vault_utils import get_secrets
 
 
+def get_hms():
+    from hmsclient import hmsclient
+
+    s = get_secrets(path="ye/hivemetastore")
+    host = s["ip"]
+    port = s["port"]
+    client = hmsclient.HMSClient(host=host, port=port)
+    client.open()
+    return client
+
+
 def get_hive_conn():
     from pyhive import hive
 
@@ -45,33 +56,7 @@ def get_spark(scale=0, queue=None):
     import uuid
     import tempfile
     from pyspark.sql import SparkSession
-    from pyspark.sql.readwriter import DataFrameWriter
     from skt.vault_utils import get_secrets
-    from skt.data_lineage import publish_relation
-
-    def add_hook(old_method):
-        def new_method(self, path, **kwargs):
-            query_execution = self._df._jdf.queryExecution().toString()
-            source = "spark"
-            destination = path
-            context = {
-                "query_execution": query_execution,
-            }
-            publish_relation(source, destination, context=context)
-            return old_method(self, path, **kwargs)
-
-        return new_method
-
-    # Add hook for data relation
-    if hasattr(DataFrameWriter, "hooked"):
-        # Avoid recursive hook add
-        pass
-    else:
-        DataFrameWriter.parquet = add_hook(DataFrameWriter.parquet)
-        DataFrameWriter.text = add_hook(DataFrameWriter.text)
-        DataFrameWriter.json = add_hook(DataFrameWriter.json)
-        DataFrameWriter.csv = add_hook(DataFrameWriter.csv)
-        DataFrameWriter.hooked = True
 
     tmp_uuid = str(uuid.uuid4())
     app_name = f"skt-{os.environ.get('USER', 'default')}-{tmp_uuid}"
@@ -101,7 +86,10 @@ def get_spark(scale=0, queue=None):
             .config("spark.port.maxRetries", "128")
             .config("spark.executorEnv.ARROW_PRE_0_15_IPC_FORMAT", "1")
             .config("spark.yarn.appMasterEnv.ARROW_PRE_0_15_IPC_FORMAT", "1")
-            .config("spark.jars", "gs://external_libs/spark/jars/spark-bigquery-with-dependencies_2.11-0.16.1.jar",)
+            .config(
+                "spark.jars",
+                "hdfs:///jars/spark-bigquery-with-dependencies_2.11-0.17.3.jar",
+            )
             .enableHiveSupport()
             .getOrCreate()
         )
@@ -120,7 +108,10 @@ def get_spark(scale=0, queue=None):
             .config("spark.port.maxRetries", "128")
             .config("spark.executorEnv.ARROW_PRE_0_15_IPC_FORMAT", "1")
             .config("spark.yarn.appMasterEnv.ARROW_PRE_0_15_IPC_FORMAT", "1")
-            .config("spark.jars", "gs://external_libs/spark/jars/spark-bigquery-with-dependencies_2.11-0.16.1.jar",)
+            .config(
+                "spark.jars",
+                "gs://external_libs/spark/jars/spark-bigquery-with-dependencies_2.11-0.16.1.jar",
+            )
             .enableHiveSupport()
             .getOrCreate()
         )
@@ -221,12 +212,46 @@ def slack_send(
         "blocks": blocks,
         "icon_emoji": icon_emoji,
     }
-    r = requests.post("https://www.slack.com/api/chat.postMessage", proxies=proxies, headers=headers, json=json_body,)
+    r = requests.post(
+        "https://www.slack.com/api/chat.postMessage",
+        proxies=proxies,
+        headers=headers,
+        json=json_body,
+    )
     r.raise_for_status()
     if not r.json()["ok"]:
         raise Exception(r.json())
 
 
+def send_email(subject, text, send_from, send_to, attachment=None):
+    """
+    :param str attachment: Attachment to send as .txt file with email
+    """
+    import smtplib
+    from email.mime.application import MIMEApplication
+    from email.mime.multipart import MIMEMultipart
+    from email.mime.text import MIMEText
+    from email.utils import formatdate
+    from skt.vault_utils import get_secrets
+
+    c = get_secrets(path="mail")
+    host, port = c["smtp_host"], c["smtp_port"]
+    msg = MIMEMultipart()
+    msg["From"] = send_from
+    msg["To"] = send_to
+    msg["Date"] = formatdate(localtime=True)
+    msg["Subject"] = subject
+    msg.attach(MIMEText(text))
+
+    if attachment:
+        part = MIMEApplication(attachment, NAME=subject)
+        part.add_header("Content-Disposition", f"attachment; filename={subject}.txt")
+        msg.attach(part)
+
+    with smtplib.SMTP(host, port) as smtp:
+        return smtp.sendmail(send_from, send_to.split(","), msg.as_string())
+
+
 def get_github_util():
     from skt.github_utils import GithubUtil
 
